==> tigerbeetle-node-0.3.0.tgz: package/src/tigerbeetle/scripts/install_zig.sh <==
#!/bin/bash
set -e

# Default to master while we wait for the 0.8.0 release:
# TODO When 0.8.0 arrives, we should make the release build the default.
if [ "$1" == "tagged" ]; then
    ZIG_RELEASE="0.7.1"
    echo "Installing Zig $ZIG_RELEASE release build..."
else
    ZIG_RELEASE="builds"
    echo "Installing Zig latest master build..."
fi

# Determine the architecture:
if [ `uname -m` == 'arm64' ] || [ `uname -m` == 'aarch64' ]; then
    ZIG_ARCH="aarch64"
else
    ZIG_ARCH="x86_64"
fi

# Determine the operating system:
if [[ "$OSTYPE" == "darwin"* ]]; then
    ZIG_OS="macos"
else
    ZIG_OS="linux"
fi

ZIG_TARGET="zig-$ZIG_OS-$ZIG_ARCH"

# Determine the 0.7.1 or latest master build, split the JSON line on whitespace and extract the 2nd field, then remove quotes and commas:
if command -v wget &> /dev/null; then
    ZIG_URL=`wget --quiet -O - https://ziglang.org/download/index.json | grep "$ZIG_TARGET" | grep "$ZIG_RELEASE" | awk '{print $2}' | sed 's/[",]//g'`
else
    ZIG_URL=`curl --silent https://ziglang.org/download/index.json | grep "$ZIG_TARGET" | grep "$ZIG_RELEASE" | awk '{print $2}' | sed 's/[",]//g'`
fi

# Work out the filename from the URL, as well as the directory without the ".tar.xz" file extension:
ZIG_TARBALL=`basename "$ZIG_URL"`
ZIG_DIRECTORY=`basename "$ZIG_TARBALL" .tar.xz`

# Download, making sure we download to the same output document, without wget adding "-1" etc. if the file was previously partially downloaded:
echo "Downloading $ZIG_URL..."
if command -v wget &> /dev/null; then
    wget --quiet --show-progress --output-document=$ZIG_TARBALL $ZIG_URL
else
    curl --silent --progress-bar --output $ZIG_TARBALL $ZIG_URL
fi

# Extract and then remove the downloaded tarball:
echo "Extracting $ZIG_TARBALL..."
tar -xf $ZIG_TARBALL
rm $ZIG_TARBALL

# Replace any existing Zig installation so that we can install or upgrade:
echo "Installing $ZIG_DIRECTORY to 'zig' in current working directory..."
rm -rf zig
mv $ZIG_DIRECTORY zig

# It's up to the user to add this to their path if they want to:
ZIG_BIN="$(pwd)/zig/zig"

ZIG_VERSION=`$ZIG_BIN version`
echo "Congratulations, you have successfully installed Zig $ZIG_VERSION to $ZIG_BIN. Enjoy!"

==> tigerbeetle-node-0.3.1.tgz: package/src/tigerbeetle/scripts/install_zig.sh <==
#!/bin/bash
set -e

if [ "$1" == "0.8.0" ]; then
    ZIG_RELEASE="0.8.0"
    echo "Installing Zig $ZIG_RELEASE release build..."
else
    ZIG_RELEASE="builds"
    echo "Installing Zig latest build..."
fi

# Determine the architecture:
if [ `uname -m` == 'arm64' ] || [ `uname -m` == 'aarch64' ]; then
    ZIG_ARCH="aarch64"
else
    ZIG_ARCH="x86_64"
fi

# Determine the operating system:
if [[ "$OSTYPE" == "darwin"* ]]; then
    ZIG_OS="macos"
else
    ZIG_OS="linux"
fi

ZIG_TARGET="zig-$ZIG_OS-$ZIG_ARCH"

# Determine the build, split the JSON line on whitespace and extract the 2nd field, then remove quotes and commas:
if command -v wget &> /dev/null; then
    ZIG_URL=`wget --quiet -O - https://ziglang.org/download/index.json | grep "$ZIG_TARGET" | grep "$ZIG_RELEASE" | awk '{print $2}' | sed 's/[",]//g'`
else
    ZIG_URL=`curl --silent https://ziglang.org/download/index.json | grep "$ZIG_TARGET" | grep "$ZIG_RELEASE" | awk '{print $2}' | sed 's/[",]//g'`
fi

# Work out the filename from the URL, as well as the directory without the ".tar.xz" file extension:
ZIG_TARBALL=`basename "$ZIG_URL"`
ZIG_DIRECTORY=`basename "$ZIG_TARBALL" .tar.xz`

# Download, making sure we download to the same output document, without wget adding "-1" etc. if the file was previously partially downloaded:
echo "Downloading $ZIG_URL..."
if command -v wget &> /dev/null; then
    wget --quiet --show-progress --output-document=$ZIG_TARBALL $ZIG_URL
else
    curl --silent --progress-bar --output $ZIG_TARBALL $ZIG_URL
fi

# Extract and then remove the downloaded tarball:
echo "Extracting $ZIG_TARBALL..."
tar -xf $ZIG_TARBALL
rm $ZIG_TARBALL

# Replace any existing Zig installation so that we can install or upgrade:
echo "Installing $ZIG_DIRECTORY to 'zig' in current working directory..."
rm -rf zig
mv $ZIG_DIRECTORY zig

# It's up to the user to add this to their path if they want to:
ZIG_BIN="$(pwd)/zig/zig"

ZIG_VERSION=`$ZIG_BIN version`
echo "Congratulations, you have successfully installed Zig $ZIG_VERSION to $ZIG_BIN. Enjoy!"
